@@ -581,6 +581,11 @@ void FemtoZip::createEntry(const char *name, int compressionLevel)
 	d->createEntry(name, compressionLevel);
 }
 
+void FemtoZip::writeData(const std::size_t length, const unsigned char *const data)
+{
+	d->writeData(length, data);
+}
+
 void FemtoZip::writeString(const char *str)
 {
 	d->writeData(strlen(str), str);
